Function cleanup_old

pub async fn cleanup_old(
    conn: impl Connection,
    older_than: DateTime<Utc>,
) -> Result<()>
Transactionally removes all completed/failed submissions, including all their chunks and associated strategic metadata.

Submissions/chunks that are neither failed nor completed are not touched.