pub struct ConsumerConn { /* private fields */ }Implementations
Sourceimpl ConsumerConn
impl ConsumerConn
pub fn new(server_state: &Arc<ServerState>, ws_stream: WebSocket) -> Self
Sourcepub async fn run(self) -> Result<(), ConsumerConnError>
pub async fn run(self) -> Result<(), ConsumerConnError>
Runs the consumer websocket connection loop Blocks until the loop is stopped (because the connection is closed intentionally or by network failure).