macro_rules! fold_both {
($value:expr, $pattern:pat => $result:expr) => { ... };
}Expand description
Similar to map_both but doesn’t wrap the result back in the respective Left/Right variant.
macro_rules! fold_both {
($value:expr, $pattern:pat => $result:expr) => { ... };
}Similar to map_both but doesn’t wrap the result back in the respective Left/Right variant.